summaryrefslogtreecommitdiff
path: root/sw/inc
diff options
context:
space:
mode:
authorJan Holesovsky <kendy@collabora.com>2013-10-16 16:36:45 +0200
committerJan Holesovsky <kendy@collabora.com>2013-10-16 16:57:22 +0200
commit66013a154bd2dccc0db1edd14197ce419ba9a614 (patch)
tree0698af88b8d236e98bafa6848f73851e0b752f15 /sw/inc
parentd62b71bddedccb6ff29090f621cc0803565332ec (diff)
[API CHANGE]: PreView -> Preview, including .uno:PrintPagePreView.
Will be .uno:PrintPagePreview going forward. Change-Id: Ie5a35467917a54a60dab9eaacf0690c9df27e6f6
Diffstat (limited to 'sw/inc')
-rw-r--r--sw/inc/accmap.hxx4
-rw-r--r--sw/inc/doc.hxx10
-rw-r--r--sw/inc/pvprtdat.hxx4
-rw-r--r--sw/inc/swcommands.h2
-rw-r--r--sw/inc/viewsh.hxx12
5 files changed, 16 insertions, 16 deletions
diff --git a/sw/inc/accmap.hxx b/sw/inc/accmap.hxx
index f1fafe6b3532..e5ad23f6af13 100644
--- a/sw/inc/accmap.hxx
+++ b/sw/inc/accmap.hxx
@@ -171,7 +171,7 @@ public:
@return an object of class <Size>
*/
- Size GetPreViewPageSize( sal_uInt16 _nPreviewPageNum ) const;
+ Size GetPreviewPageSize( sal_uInt16 _nPreviewPageNum ) const;
void RemoveContext( const SwFrm *pFrm );
void RemoveContext( const SdrObject *pObj );
@@ -240,7 +240,7 @@ public:
const SwPageFrm* _pSelectedPageFrm,
const Size& _rPreviewWinSize );
- void InvalidatePreViewSelection( sal_uInt16 nSelPage );
+ void InvalidatePreviewSelection( sal_uInt16 nSelPage );
bool IsPageSelected( const SwPageFrm *pPageFrm ) const;
void FireEvents();
diff --git a/sw/inc/pvprtdat.hxx b/sw/inc/pvprtdat.hxx
index 513b1b3dabe3..65d0adf41c13 100644
--- a/sw/inc/pvprtdat.hxx
+++ b/sw/inc/pvprtdat.hxx
@@ -23,14 +23,14 @@
#include <tools/solar.h>
-class SwPagePreViewPrtData
+class SwPagePreviewPrtData
{
sal_uLong nLeftSpace, nRightSpace, nTopSpace, nBottomSpace,
nHorzSpace, nVertSpace;
sal_uInt8 nRow, nCol;
sal_Bool bLandscape : 1;
public:
- SwPagePreViewPrtData()
+ SwPagePreviewPrtData()
: nLeftSpace(0), nRightSpace(0), nTopSpace(0), nBottomSpace(0),
nHorzSpace(0), nVertSpace(0), nRow(1), nCol(1),
bLandscape(0)
diff --git a/sw/inc/swcommands.h b/sw/inc/swcommands.h
index 6722b2d5d8f4..6649063481a0 100644
--- a/sw/inc/swcommands.h
+++ b/sw/inc/swcommands.h
@@ -75,7 +75,7 @@
#define CMD_FN_FORMAT_PAGE_DLG ".uno:PageDialog"
#define CMD_FN_PAGEDOWN ".uno:PageDown"
#define CMD_FN_PAGEUP ".uno:PageUp"
-#define CMD_FN_PRINT_PAGEPREVIEW ".uno:PrintPagePreView"
+#define CMD_FN_PRINT_PAGEPREVIEW ".uno:PrintPagePreview"
#define CMD_FN_TABLE_SET_READ_ONLY_CELLS ".uno:Protect"
#define CMD_FN_REMOVE_CUR_TOX ".uno:RemoveTableOf"
#define CMD_FN_FORMAT_RESET ".uno:ResetAttributes"
diff --git a/sw/inc/doc.hxx b/sw/inc/doc.hxx
index 2ce96053c30d..42379e40d686 100644
--- a/sw/inc/doc.hxx
+++ b/sw/inc/doc.hxx
@@ -142,7 +142,7 @@ class SwNodes;
class SwNumRule;
class SwNumRuleTbl;
class SwPageDesc;
-class SwPagePreViewPrtData;
+class SwPagePreviewPrtData;
class SwRedline;
class SwRedlineTbl;
class SwRootFrm;
@@ -362,7 +362,7 @@ class SW_DLLPUBLIC SwDoc :
SwUnoCrsrTbl *mpUnoCrsrTbl;
- SwPagePreViewPrtData *mpPgPViewPrtData; ///< Indenting / spacing for printing of page view.
+ SwPagePreviewPrtData *mpPgPViewPrtData; ///< Indenting / spacing for printing of page view.
SwPaM *mpExtInputRing;
SwLayouter *mpLayouter; /**< ::com::sun::star::frame::Controller for complex layout formatting
@@ -1866,13 +1866,13 @@ public:
/// Only for SW-textbloxks! Does not pay any attention to layout!
void ClearDoc(); // Deletes all content!
- /// Query /set data for PagePreView.
- const SwPagePreViewPrtData* GetPreViewPrtData() const { return mpPgPViewPrtData; }
+ /// Query /set data for PagePreview.
+ const SwPagePreviewPrtData* GetPreviewPrtData() const { return mpPgPViewPrtData; }
// If pointer == 0 destroy pointer in document.
// Else copy object.
// Pointer is not transferred to ownership by document!
- void SetPreViewPrtData( const SwPagePreViewPrtData* pData );
+ void SetPreviewPrtData( const SwPagePreviewPrtData* pData );
/** update all modified OLE-Objects. The modification is called over the
StarOne - Interface */
diff --git a/sw/inc/viewsh.hxx b/sw/inc/viewsh.hxx
index 7fcd7d135ba0..a106b9657afb 100644
--- a/sw/inc/viewsh.hxx
+++ b/sw/inc/viewsh.hxx
@@ -59,7 +59,7 @@ class SfxViewShell;
class SwViewOption;
class SwViewImp;
class SwPrintData;
-class SwPagePreViewPrtData;
+class SwPagePreviewPrtData;
class Window;
class OutputDevice;
class SwLayIdle;
@@ -90,7 +90,7 @@ enum FrameControlType
};
// Define for flags needed in ctor or layers below.
-// Currently the PreView flag is needed for DrawPage.
+// Currently the Preview flag is needed for DrawPage.
#define VSHELLFLAG_ISPREVIEW ((long)0x1)
#define VSHELLFLAG_SHARELAYOUT ((long)0x2)//swmod 080125 flag
typedef boost::shared_ptr<SwRootFrm> SwRootFrmPtr;
@@ -147,7 +147,7 @@ class SW_DLLPUBLIC ViewShell : public Ring
sal_Bool mbViewLocked :1; // Lock visible range;
// in this case MakeVisible is ineffectual.
sal_Bool mbInEndAction :1; // Avoid problems, cf. viewsh.cxx.
- sal_Bool mbPreView :1; // If sal_True it is a PreView-ViewShell.
+ sal_Bool mbPreview :1; // If sal_True it is a Preview-ViewShell.
sal_Bool mbFrameView :1; // If sal_True it is a (HTML-)Frame.
sal_Bool mbEnableSmooth :1; // Disable SmoothScroll, e.g. for drag
// of scrollbars.
@@ -174,7 +174,7 @@ class SW_DLLPUBLIC ViewShell : public Ring
SW_DLLPRIVATE void PaintDesktop( const SwRect & ); // Collect values for painting of desktop
// and calling.
// PaintDesktop split. This pars is also used by PreViewPage.
SW_DLLPRIVATE void _PaintDesktop( const SwRegionRects &rRegion );
SW_DLLPRIVATE sal_Bool CheckInvalidForPaint( const SwRect & ); // Direct Paint or rather
@@ -477,7 +477,7 @@ public:
inline const SfxItemPool& GetAttrPool() const;
SfxItemPool& GetAttrPool();
- sal_Bool IsPreView() const { return mbPreView; }
+ sal_Bool IsPreview() const { return mbPreview; }
sal_Bool IsFrameView() const { return mbFrameView; }
void SetFrameView( const Size& rBrowseBorder )
@@ -499,7 +499,7 @@ public:
::com::sun::star::accessibility::XAccessible >
CreateAccessiblePreview();
- void ShowPreViewSelection( sal_uInt16 nSelPage );
+ void ShowPreviewSelection( sal_uInt16 nSelPage );
void InvalidateAccessibleFocus();
// Apply Accessiblity options.
@@ -174,7 +174,7 @@ class SW_DLLPUBLIC ViewShell : public Ring
SW_DLLPRIVATE void PaintDesktop( const SwRect & ); // Collect values for painting of desktop
// and calling.
- // PaintDesktop split. This pars is also used by PreViewPage.
+ // PaintDesktop split. This pars is also used by PreviewPage.
SW_DLLPRIVATE void _PaintDesktop( const SwRegionRects &rRegion );
SW_DLLPRIVATE sal_Bool CheckInvalidForPaint( const SwRect & ); // Direct Paint or rather